# ProMoAI
ProMoAI is a Streamlit app that leverages Large Language Models (currently OpenAI's models) for the automatic generation of process models. ProMoAI transforms textual descriptions of processes into process models that can be exported in the BPMN and PNML formats. It also supports user interaction by providing feedback on the generated model to refine it.

## Launching the App
You have two options for running ProMoAI.
* *On the cloud:* under https://promoai.streamlit.app/.
* *Locally:* by cloning this repository, installing the required environment and packages, and then running 'streamlit run app.py'.


## Requirements

* *Environment:* the app is tested on both Python 3.9 and 3.10.
* *Dependencies:* all required dependencies are listed in the file 'requirements.txt'.
* *Packages:* all required packages are listed in the file 'packages.txt'.
